;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "jedi" "20250602.2107"
  "A Python auto-completion for Emacs."
  '((emacs         "24")
    (jedi-core     "0.2.2")
    (auto-complete "1.4"))
  :url "https://github.com/tkf/emacs-jedi"
  :commit "0a92f57dcfd76f1daf6d382d1e2eb437784a71e0"
  :revdesc "0a92f57dcfd7"
  :authors '(("Takafumi Arakaki" . "aka.tkfatgmail.com"))
  :maintainers '(("Takafumi Arakaki" . "aka.tkfatgmail.com")))
